pub fn empty_env() -> Environment👎Deprecated since 0.10.0:
Use Environment::empty() instead
An empty environment at the root of the environment tree
pub fn empty_env() -> EnvironmentUse Environment::empty() instead
An empty environment at the root of the environment tree